From 9ca5fbcb63a8dcaee0527f96afb91dc4b4bd8fa9 Mon Sep 17 00:00:00 2001
From: hc <hc@nodka.com>
Date: Wed, 22 Nov 2023 01:08:11 +0000
Subject: [PATCH] add ip1811 driver

---
 kernel/include/linux/pstore_ram.h |   20 ++++++++++----------
 1 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/kernel/include/linux/pstore_ram.h b/kernel/include/linux/pstore_ram.h
index 69e580b..82ffcac 100644
--- a/kernel/include/linux/pstore_ram.h
+++ b/kernel/include/linux/pstore_ram.h
@@ -76,8 +76,8 @@
 	struct persistent_ram_zone *cprz;	/* Console zone */
 	struct persistent_ram_zone **fprzs;	/* Ftrace zones */
 	struct persistent_ram_zone *mprz;	/* PMSG zone */
-#ifdef CONFIG_PSTORE_MCU_LOG
-	struct persistent_ram_zone **mcu_przs;	/* MCU log zones */
+#ifdef CONFIG_PSTORE_BOOT_LOG
+	struct persistent_ram_zone **boot_przs;	/* BOOT log zones */
 #endif
 	phys_addr_t phys_addr;
 	unsigned long size;
@@ -86,8 +86,8 @@
 	size_t console_size;
 	size_t ftrace_size;
 	size_t pmsg_size;
-#ifdef CONFIG_PSTORE_MCU_LOG
-	size_t mcu_log_size;
+#ifdef CONFIG_PSTORE_BOOT_LOG
+	size_t boot_log_size;
 #endif
 	int dump_oops;
 	u32 flags;
@@ -100,9 +100,9 @@
 	unsigned int max_ftrace_cnt;
 	unsigned int ftrace_read_cnt;
 	unsigned int pmsg_read_cnt;
-#ifdef CONFIG_PSTORE_MCU_LOG
-	unsigned int mcu_log_read_cnt;
-	unsigned int max_mcu_log_cnt;
+#ifdef CONFIG_PSTORE_BOOT_LOG
+	unsigned int boot_log_read_cnt;
+	unsigned int max_boot_log_cnt;
 #endif
 	struct pstore_info pstore;
 };
@@ -141,9 +141,9 @@
 	unsigned long	console_size;
 	unsigned long	ftrace_size;
 	unsigned long	pmsg_size;
-#ifdef CONFIG_PSTORE_MCU_LOG
-	unsigned long	mcu_log_size;
-	unsigned long	max_mcu_log_cnt;
+#ifdef CONFIG_PSTORE_BOOT_LOG
+	unsigned long	boot_log_size;
+	unsigned long	max_boot_log_cnt;
 #endif
 	int		dump_oops;
 	u32		flags;

--
Gitblit v1.6.2